@@ -1,6 +1,6 @@
 /* FAudio - XAudio Reimplementation for FNA
  *
- * Copyright (c) 2011-2023 Ethan Lee, Luigi Auriemma, and the MonoGame Team
+ * Copyright (c) 2011-2024 Ethan Lee, Luigi Auriemma, and the MonoGame Team
  *
  * This software is provided 'as-is', without any express or implied warranty.
  * In no event will the authors be held liable for any damages arising from
@@ -44,6 +44,12 @@
 extern "C" {
 #endif /* __cplusplus */
 
+#define FACTENGINE_E_NONOTIFICATIONCALLBACK	0x8ac70004
+#define FACTENGINE_E_INVALIDUSAGE		0x8ac70006
+#define FACTENGINE_E_INVALIDDATA		0x8ac70007
+#define FACTENGINE_E_INSTANCELIMITFAILTOPLAY	0x8ac70008
+#define FACTENGINE_E_INVALIDVARIABLEINDEX	0x8ac7000a
+
 /* Type Declarations */
 
 typedef struct FACTAudioEngine FACTAudioEngine;
@@ -124,6 +130,11 @@ typedef struct FACTStreamingParameters
 	uint16_t packetSize; /* Measured in DVD sectors, or 2048 bytes */
 } FACTStreamingParameters;
 
+#define FACT_WAVEBANKMINIFORMAT_TAG_PCM		0x0
+#define FACT_WAVEBANKMINIFORMAT_TAG_XMA		0x1
+#define FACT_WAVEBANKMINIFORMAT_TAG_ADPCM	0x2
+#define FACT_WAVEBANKMINIFORMAT_TAG_WMA		0x3
+
 #define FACT_WAVEBANK_TYPE_BUFFER		0x00000000
 #define FACT_WAVEBANK_TYPE_STREAMING		0x00000001
 #define FACT_WAVEBANK_TYPE_MASK			0x00000001
