@@ -341,6 +341,8 @@ typedef struct FAudioXMA2WaveFormatEx
 
 /* Constants */
 
+#define FAUDIO_OK			0x0
+#define FAUDIO_E_FAIL			0x80004005
 #define FAUDIO_E_OUT_OF_MEMORY		0x8007000e
 #define FAUDIO_E_INVALID_ARG		0x80070057
 #define FAUDIO_E_UNSUPPORTED_FORMAT	0x88890008
@@ -493,8 +495,8 @@ extern FAudioGUID DATAFORMAT_SUBTYPE_IEEE_FLOAT;
 #define FAUDIO_TARGET_VERSION 8 /* Targeting compatibility with XAudio 2.8 */
 
 #define FAUDIO_ABI_VERSION	 0
-#define FAUDIO_MAJOR_VERSION	25
-#define FAUDIO_MINOR_VERSION	 9
+#define FAUDIO_MAJOR_VERSION	26
+#define FAUDIO_MINOR_VERSION	 1
 #define FAUDIO_PATCH_VERSION	 0
 
 #define FAUDIO_COMPILED_VERSION ( \
